@@ -22,6 +22,8 @@
 #include "config.h"
 #include "empathy-chatroom.h"
 
+#include <tp-account-widgets/tpaw-utils.h>
+
 #include "empathy-utils.h"
 
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyChatroom)
@@ -413,7 +415,7 @@ empathy_chatroom_get_name (EmpathyChatroom *chatroom)
 
 	priv = GET_PRIV (chatroom);
 
-	if (EMP_STR_EMPTY (priv->name)) {
+	if (TPAW_STR_EMPTY (priv->name)) {
 		return priv->room;
 	}
 
