@@ -27,6 +27,7 @@
 #include "empathy-chatrooms-window.h"
 
 #include <glib/gi18n.h>
+#include <tp-account-widgets/tpaw-builder.h>
 
 #include "empathy-account-chooser.h"
 #include "empathy-chatroom-manager.h"
@@ -100,16 +101,16 @@ empathy_chatrooms_window_show (GtkWindow *parent)
 	window = g_new0 (EmpathyChatroomsWindow, 1);
 
 	filename = empathy_file_lookup ("empathy-chatrooms-window.ui", "src");
-	gui = empathy_builder_get_file (filename,
-				       "chatrooms_window", &window->window,
-				       "hbox_account", &window->hbox_account,
-				       "label_account", &window->label_account,
-				       "sw_room_list", &sw,
-				       "treeview", &window->treeview,
-				       "toolbar_remove", &toolbar,
-				       "button_remove", &window->button_remove,
-				       "button_close", &window->button_close,
-				       NULL);
+	gui = tpaw_builder_get_file (filename,
+				     "chatrooms_window", &window->window,
+				     "hbox_account", &window->hbox_account,
+				     "label_account", &window->label_account,
+				     "sw_room_list", &sw,
+				     "treeview", &window->treeview,
+				     "toolbar_remove", &toolbar,
+				     "button_remove", &window->button_remove,
+				     "button_close", &window->button_close,
+				     NULL);
 	g_free (filename);
 
 	/* join the remove toolbar to the treeview */
@@ -118,7 +119,7 @@ empathy_chatrooms_window_show (GtkWindow *parent)
 	context = gtk_widget_get_style_context (toolbar);
 	gtk_style_context_set_junction_sides (context, GTK_JUNCTION_TOP);
 
-	empathy_builder_connect (gui, window,
+	tpaw_builder_connect (gui, window,
 			      "chatrooms_window", "destroy", chatrooms_window_destroy_cb,
 			      "button_remove", "clicked", chatrooms_window_button_remove_clicked_cb,
 			      "button_close", "clicked", chatrooms_window_button_close_clicked_cb,
